==> landers.angular-1.0.92.tgz: package/src/control/directive-landers-upload.js <==
;angular.module('Landers.angular')
    .directive('landersUpload', function($rootScope, Flat) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs) {
                Landers.loader.jsm(['landers.iframe', 'landers.upload,true'], function(){
                    var $form = $element.closest('form');
                    var rel = $element.attr('rel');
                    var $rel = $form.find('#' + rel);
                    var relModel = $rel.attr('ng-model');
                    $rel.val(Flat.get($scope, relModel) || '');

                    var relsmall = $element.attr('rel_small');
                    if (relsmall) {
                        var $relsmall = $form.find('#' + relsmall);
                        var relsmallModel = $relsmall.attr('ng-model');
                        $relsmall.val(Flat.get($scope, relsmallModel) || '');
                    }
                    var tipid = $element.attr('tipid');
                    var $tip = $form.find('#' + tipid);
                    var params = $element.attr('params');
                    if (params) params = angular.fromJson(params); else params = {};
                    $scope.$watch(
                        function(){return $rel.val()},
                        function(newValue){
                            Flat.set($scope, relModel, newValue);
                        }
                    );
                    if (relsmall && $relsmall.length && relsmallModel) {
                        $scope.$watch(
                            function(){return $relsmall.val()},
                            function(newValue){
                                Flat.set($scope, relsmallModel, newValue);
                            }
                        );
                    };
                    var opts = {scope:$scope};
                    if (relsmall && $relsmall.length) opts.$small = $relsmall;
                    if ($tip.length)  opts.$tip = $tip;
                    opts.faces = $element.attr('faces') || 0;

                    var pvw = $element.attr('pvw'), pvh = $element.attr('pvh');
                    if (pvw || pvh) {
                        opts.pvsize = {};
                        if (pvw) opts.pvsize.width = pvw;
                        if (pvh) opts.pvsize.height = pvh;
                    };
                    opts.onload = function(){
                        var upload = this;
                        if (params.init_logo) {
                            var $faces = upload.getfaces();
                            $faces.each(function(){
                                Upload.plug.attach_setlogo($(this), params.init_logo, 'val_small');
                            });
                        };
                    };
                    opts.onchange = function(){
                        if (!$scope.$$phase) $scope.$apply();
                    };
                    opts = $.extend({}, opts, params);
                    opts.hosturl = $rootScope.$settings.env.upload_host_url;
                    opts.debug = !!params.debug;
                    Landers.upload.create(
                        $element.attr('uploadid'),
                        params.apiurl || 'upload.php', $element, $rel, opts
                    );
                });
            }
        };
    });

==> landers.angular-2.0.24.tgz: package/src/control/directive-landers-upload.js <==
;angular.module('Landers.angular')
    .directive('landersUpload', function($rootScope, Flat) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs) {
                var upload_host_url = $attrs['uploadHostUrl'];
                var upload_api_url = $attrs['uploadApiUrl'];
                Landers.loader.jsm(['landers.iframe', 'landers.upload,true'], function(){
                    var $form = $element.closest('form');
                    var rel = $element.attr('rel');
                    var $rel = $form.find('#' + rel);
                    var relModel = $rel.attr('ng-model');
                    $rel.val(Flat.get($scope, relModel) || '');

                    var relsmall = $element.attr('rel_small');
                    if (relsmall) {
                        var $relsmall = $form.find('#' + relsmall);
                        var relsmallModel = $relsmall.attr('ng-model');
                        $relsmall.val(Flat.get($scope, relsmallModel) || '');
                    }
                    var tipid = $element.attr('tipid');
                    var $tip = $form.find('#' + tipid);
                    var params = $element.attr('params');
                    if (params) params = angular.fromJson(params); else params = {};
                    $scope.$watch(
                        function(){return $rel.val()},
                        function(newValue){
                            Flat.set($scope, relModel, newValue);
                        }
                    );
                    if (relsmall && $relsmall.length && relsmallModel) {
                        $scope.$watch(
                            function(){return $relsmall.val()},
                            function(newValue){
                                Flat.set($scope, relsmallModel, newValue);
                            }
                        );
                    };
                    var opts = {scope:$scope};
                    if (relsmall && $relsmall.length) opts.$small = $relsmall;
                    if ($tip.length)  opts.$tip = $tip;
                    opts.faces = $element.attr('faces') || 0;

                    var pvw = $element.attr('pvw'), pvh = $element.attr('pvh');
                    if (pvw || pvh) {
                        opts.pvsize = {};
                        if (pvw) opts.pvsize.width = pvw;
                        if (pvh) opts.pvsize.height = pvh;
                    };
                    opts.onload = function(){
                        var upload = this;
                        if (params.init_logo) {
                            var $faces = upload.getfaces();
                            $faces.each(function(){
                                Upload.plug.attach_setlogo($(this), params.init_logo, 'val_small');
                            });
                        };
                    };
                    opts.onchange = function(){
                        if (!$scope.$$phase) $scope.$apply();
                    };
                    opts = $.extend({}, opts, params);
                    opts.hosturl = upload_host_url || $rootScope.$settings.env.upload_host_url;
                    opts.debug = !!params.debug;
                    Landers.upload.create(
                        $element.attr('uploadid'),
                        upload_api_url || params.apiurl || 'upload.php',
                        $element, $rel, opts
                    );
                });
            }
        };
    });
